/******************************************************************************
 GMSaveFileDialog.cc

	Clients must call BuildWindow() after constructing the object.

	BASE CLASS = JXSaveFileDialog

	Written by John Lindal.

 ******************************************************************************/

#include "GMSaveFileDialog.h"

#include <JXWindow.h>
#include <JXStaticText.h>
#include <JXSaveFileInput.h>
#include <JXPathInput.h>
#include <JXTextButton.h>
#include <JXTextCheckbox.h>
#include <JXTextCheckbox.h>
#include <JXPathHistoryMenu.h>
#include <JXScrollbarSet.h>
#include <JXNewDirButton.h>

#include <JString.h>

#include <jAssert.h>

/******************************************************************************
 Constructor

 ******************************************************************************/

GMSaveFileDialog::GMSaveFileDialog
	(
	JXDirector*			supervisor,
	JUNIXDirInfo*		dirInfo,
	const JCharacter*	fileFilter,
	const JCharacter*	origName,
	const JCharacter*	prompt,
	const JCharacter*	message
	)
	:
	JXSaveFileDialog(supervisor, dirInfo, fileFilter)
{
	BuildWindow(origName, prompt, message);
}

/******************************************************************************
 Destructor

 ******************************************************************************/

GMSaveFileDialog::~GMSaveFileDialog()
{
}

/******************************************************************************
 SaveHeaders

 ******************************************************************************/

JBoolean
GMSaveFileDialog::IsSavingHeaders()
	const
{
	return itsShowHeadersCB->IsChecked();
}

void
GMSaveFileDialog::ShouldSaveHeaders
	(
	const JBoolean save
	)
{
	itsShowHeadersCB->SetState(save);
}

/******************************************************************************
 BuildWindow

 ******************************************************************************/

void
GMSaveFileDialog::BuildWindow
	(
	const JCharacter*	origName,
	const JCharacter*	prompt,
	const JCharacter*	message
	)
{
// begin JXLayout

    JXWindow* window = new JXWindow(this, 310,340, "");
    assert( window != NULL );
    SetWindow(window);

    JXScrollbarSet* scrollbarSet =
        new JXScrollbarSet(window,
                    JXWidget::kHElastic, JXWidget::kFixedBottom, 20,110, 180,140);
    assert( scrollbarSet != NULL );

    JXTextButton* saveButton =
        new JXTextButton("Save", window,
                    JXWidget::kFixedRight, JXWidget::kFixedBottom, 219,249, 72,22);
    assert( saveButton != NULL );
    saveButton->SetShortcuts("^M");

    JXTextButton* cancelButton =
        new JXTextButton("Cancel", window,
                    JXWidget::kFixedRight, JXWidget::kFixedBottom, 220,280, 70,20);
    assert( cancelButton != NULL );
    cancelButton->SetShortcuts("^[");

    JXTextButton* homeButton =
        new JXTextButton("Home", window,
                    JXWidget::kFixedRight, JXWidget::kFixedBottom, 250,110, 40,20);
    assert( homeButton != NULL );
    homeButton->SetShortcuts("#H");

    JXStaticText* pathLabel =
        new JXStaticText("Path:", window,
                    JXWidget::kFixedLeft, JXWidget::kFixedBottom, 20,20, 40,20);
    assert( pathLabel != NULL );

    JXSaveFileInput* fileNameInput =
        new JXSaveFileInput(window,
                    JXWidget::kHElastic, JXWidget::kFixedBottom, 20,280, 180,20);
    assert( fileNameInput != NULL );

    JXPathInput* pathInput =
        new JXPathInput(window,
                    JXWidget::kHElastic, JXWidget::kFixedBottom, 60,20, 200,20);
    assert( pathInput != NULL );

    JXTextCheckbox* showHiddenCB =
        new JXTextCheckbox("Show hidden files", window,
                    JXWidget::kFixedLeft, JXWidget::kFixedBottom, 60,80, 130,20);
    assert( showHiddenCB != NULL );
    showHiddenCB->SetShortcuts("#S");

    JXStaticText* promptLabel =
        new JXStaticText("", window,
                    JXWidget::kHElastic, JXWidget::kFixedBottom, 20,260, 180,20);
    assert( promptLabel != NULL );

    JXStaticText* filterLabel =
        new JXStaticText("Filter:", window,
                    JXWidget::kFixedLeft, JXWidget::kFixedBottom, 20,50, 40,20);
    assert( filterLabel != NULL );

    JXInputField* filterInput =
        new JXInputField(window,
                    JXWidget::kHElastic, JXWidget::kFixedBottom, 60,50, 200,20);
    assert( filterInput != NULL );

    JXPathHistoryMenu* pathHistory =
        new JXPathHistoryMenu(1, "", window,
                    JXWidget::kFixedRight, JXWidget::kFixedBottom, 260,20, 30,20);
    assert( pathHistory != NULL );

    JXStringHistoryMenu* filterHistory =
        new JXStringHistoryMenu(1, "", window,
                    JXWidget::kFixedRight, JXWidget::kFixedBottom, 260,50, 30,20);
    assert( filterHistory != NULL );

    JXTextButton* upButton =
        new JXTextButton("Up", window,
                    JXWidget::kFixedRight, JXWidget::kFixedBottom, 220,110, 30,20);
    assert( upButton != NULL );
    upButton->SetShortcuts("#U");

    JXNewDirButton* newDirButton =
        new JXNewDirButton(window,
                    JXWidget::kFixedRight, JXWidget::kFixedBottom, 220,140, 70,20);
    assert( newDirButton != NULL );

    itsShowHeadersCB =
        new JXTextCheckbox("Save headers", window,
                    JXWidget::kFixedLeft, JXWidget::kFixedBottom, 20,310, 190,20);
    assert( itsShowHeadersCB != NULL );

// end JXLayout

	SetObjects(scrollbarSet, promptLabel, prompt, fileNameInput, origName,
			   pathLabel, pathInput, pathHistory,
			   filterLabel, filterInput, filterHistory,
			   saveButton, cancelButton, upButton, homeButton, newDirButton,
			   showHiddenCB, message);

	itsShowHeadersCB->SetState(kFalse);
}
